@@ -22,7 +22,7 @@
 #include <stdio.h>
 #include <string.h>
 
-#include "st.h"
+#include "st_i.h"
 
 #define AVR_MAGIC "2BIT"
 
@@ -38,11 +38,11 @@ typedef struct avrstuff {
   unsigned short midi; /* 0xffff = no MIDI note assigned,
 			  0xffXX = single key note assignment
 			  0xLLHH = key split, low/hi note */
-  ULONG rate;	       /* sample frequency in hertz */
-  ULONG size;	       /* sample length in bytes or words (see rez) */
-  ULONG lbeg;	       /* offset to start of loop in bytes or words.
+  uint32_t rate;       /* sample frequency in hertz */
+  uint32_t size;       /* sample length in bytes or words (see rez) */
+  uint32_t lbeg;       /* offset to start of loop in bytes or words.
 			  set to zero if unused. */
-  ULONG lend;	       /* offset to end of loop in bytes or words.
+  uint32_t lend;       /* offset to end of loop in bytes or words.
 			  set to sample length if unused. */
   unsigned short res1; /* Reserved, MIDI keyboard split */
   unsigned short res2; /* Reserved, sample compression */
@@ -262,9 +262,7 @@ ft_t ft;
   return(ST_SUCCESS);
 }
 
-LONG st_avrwrite(ft, buf, nsamp) 
-ft_t ft;
-LONG *buf, nsamp;
+st_ssize_t st_avrwrite(ft_t ft, st_sample_t *buf, st_ssize_t nsamp) 
 {
   avr_t	avr = (avr_t)ft->priv;
 
@@ -273,10 +271,7 @@ LONG *buf, nsamp;
   return (st_rawwrite (ft, buf, nsamp));
 }
 
-
-
-int st_avrstopwrite(ft) 
-ft_t ft;
+int st_avrstopwrite(ft_t ft) 
 {
   avr_t	avr = (avr_t)ft->priv;
   int rc;
