@@ -236,6 +236,11 @@ static char *vorbisnames[] = {
 };
 #endif
 
+static char *voxnames[] = {
+        "vox",
+        (char *) 0
+};
+
 /* Microsoftt RIFF */
 static char *wavnames[] = {
         "wav",
@@ -320,8 +325,8 @@ st_format_t st_formats[] = {
         st_ossdspstartwrite, st_rawwrite, st_rawstopwrite, st_format_nothing_seek},
 #endif
     {prcnames, ST_FILE_SEEK,
-	st_prcstartread, st_prcread, st_rawstopread,
-	st_prcstartwrite, st_prcwrite, st_prcstopwrite, st_prcseek},
+        st_prcstartread, st_prcread, st_rawstopread,
+        st_prcstartwrite, st_prcwrite, st_prcstopwrite, st_prcseek},
     {rawnames, ST_FILE_STEREO | ST_FILE_SEEK,
         st_rawstartread, st_rawread, st_rawstopread,
         st_rawstartwrite, st_rawwrite, st_rawstopwrite, st_rawseek},
@@ -335,7 +340,7 @@ st_format_t st_formats[] = {
         st_slstartread, st_rawread, st_rawstopread,
         st_slstartwrite, st_rawwrite, st_rawstopwrite, st_format_nothing_seek},
     {smpnames, ST_FILE_STEREO | ST_FILE_LOOPS | ST_FILE_SEEK,
-        st_smpstartread, st_smpread, st_format_nothing,
+        st_smpstartread, st_smpread, st_smpstopread,
         st_smpstartwrite, st_smpwrite, st_smpstopwrite, st_smpseek},
     {sndtnames, ST_FILE_STEREO | ST_FILE_SEEK,
         st_sndtstartread, st_rawread, st_rawstopread,
@@ -376,14 +381,18 @@ st_format_t st_formats[] = {
         st_vorbisstartwrite, st_vorbiswrite, st_vorbisstopwrite,
         st_format_nothing_seek},
 #endif
+    {voxnames, 0,
+        st_voxstartread, st_voxread, st_voxstopread,
+        st_voxstartwrite, st_voxwrite, st_voxstopwrite,
+        st_format_nothing_seek},
     {wavnames, ST_FILE_STEREO | ST_FILE_SEEK,
-        st_wavstartread, st_wavread, st_format_nothing,
+        st_wavstartread, st_wavread, st_wavstopread,
         st_wavstartwrite, st_wavwrite, st_wavstopwrite, st_wavseek},
     {wvenames, ST_FILE_SEEK,
         st_wvestartread, st_wveread, st_rawstopread,
         st_wvestartwrite, st_wvewrite, st_wvestopwrite, st_wveseek},
     {0, 0,
-        0, 0, 0, 0, 0, 0}
+        0, 0, 0, 0, 0, 0, 0}
 };
 
 /* Effects handlers. */
@@ -465,6 +474,9 @@ st_effect_t st_effects[] = {
         {"phaser", 0,
                 st_phaser_getopts, st_phaser_start, st_phaser_flow,
                 st_phaser_drain, st_phaser_stop},
+        {"pick", ST_EFF_MCHAN | ST_EFF_CHAN,
+                st_avg_getopts, st_avg_start, st_avg_flow,
+                st_effect_nothing_drain, st_avg_stop},
         {"pitch", 0,
                 st_pitch_getopts, st_pitch_start, st_pitch_flow,
                 st_pitch_drain, st_pitch_stop},
@@ -474,6 +486,9 @@ st_effect_t st_effects[] = {
         {"rate", ST_EFF_RATE,
                 st_rate_getopts, st_rate_start, st_rate_flow,
                 st_effect_nothing_drain, st_effect_nothing},
+        {"repeat", 0,
+                st_repeat_getopts, st_repeat_start, st_repeat_flow,
+                st_repeat_drain, st_repeat_stop},
         {"resample", ST_EFF_RATE,
                 st_resample_getopts, st_resample_start, st_resample_flow,
                 st_resample_drain, st_resample_stop},
